@@ -6,7 +6,7 @@
 # ownership. All rights reserved. This program and the accompanying materials are made available
 # under the terms of the Apache License, Version 2.0 which accompanies this distribution and is
 # available at http://www.apache.org/licenses/LICENSE-2.0.txt
-#===============================================================================================
+# ===============================================================================================
 """
 This module contains classes that are used in constructing queries and their constraints.
 
@@ -14,14 +14,20 @@ It contains the following import shortcuts:
 ```python
 from pygw.query import Query
 from pygw.query import QueryConstraints
+from pygw.query import QueryConstraintsFactory
 from pygw.query import QueryHintKey
+from pygw.query import AggregationQuery
 from pygw.query import VectorQueryBuilder
+from pygw.query import VectorAggregationQueryBuilder
 from pygw.query import FilterFactory
 ```
 """
 
 from .query import Query
 from .query_constraints import QueryConstraints
+from .query_constraints_factory import QueryConstraintsFactory
 from .query_hint_key import QueryHintKey
+from .aggregation_query import AggregationQuery
+from .vector import VectorAggregationQueryBuilder
 from .vector import VectorQueryBuilder
 from .vector import FilterFactory
