@@ -6,7 +6,7 @@
 # ownership. All rights reserved. This program and the accompanying materials are made available
 # under the terms of the Apache License, Version 2.0 which accompanies this distribution and is
 # available at http://www.apache.org/licenses/LICENSE-2.0.txt
-#===============================================================================================
+# ===============================================================================================
 """
 This module contains the classes needed for querying vector data.
 
@@ -15,13 +15,13 @@ It contains the following import shortcuts:
 from pygw.query.vector import SpatialTemporalConstraintsBuilder
 from pygw.query.vector import VectorQueryConstraintsFactory
 from pygw.query.vector import FilterFactory
-from pygw.query.vector import SimpleFeatureTransformer
 from pygw.query.vector import VectorQueryBuilder
+from pygw.query.vector import VectorAggregationQueryBuilder
 ```
 """
 
 from .spatial_temporal_constraints_builder import SpatialTemporalConstraintsBuilder
 from .vector_query_constraints_factory import VectorQueryConstraintsFactory
 from .filter_factory import FilterFactory
-from .simple_feature_transformer import SimpleFeatureTransformer
 from .vector_query_builder import VectorQueryBuilder
+from .vector_aggregation_query_builder import VectorAggregationQueryBuilder
