@@ -6,14 +6,15 @@
 # ownership. All rights reserved. This program and the accompanying materials are made available
 # under the terms of the Apache License, Version 2.0 which accompanies this distribution and is
 # available at http://www.apache.org/licenses/LICENSE-2.0.txt
-#===============================================================================================
+# ===============================================================================================
 
 from pygw.config import geowave_pkg
 
+from ...geotools.simple_feature import SimpleFeatureTransformer
 from ..query_builder import QueryBuilder
-from .simple_feature_transformer import SimpleFeatureTransformer
 from .vector_query_constraints_factory import VectorQueryConstraintsFactory
 
+
 class VectorQueryBuilder(QueryBuilder):
     """
     A builder for creating queries for vector data.
