@@ -6,14 +6,15 @@
 # ownership. All rights reserved. This program and the accompanying materials are made available
 # under the terms of the Apache License, Version 2.0 which accompanies this distribution and is
 # available at http://www.apache.org/licenses/LICENSE-2.0.txt
-#===============================================================================================
+# ===============================================================================================
 
 from pygw.config import geowave_pkg
 
 from .data_store import DataStore
 from .data_store_options import DataStoreOptions
 
-class DataStoreFactory():
+
+class DataStoreFactory:
     """
     Factory class for creating a data store from a given set of options.
     """
