@@ -6,7 +6,7 @@
 # ownership. All rights reserved. This program and the accompanying materials are made available
 # under the terms of the Apache License, Version 2.0 which accompanies this distribution and is
 # available at http://www.apache.org/licenses/LICENSE-2.0.txt
-#===============================================================================================
+# ===============================================================================================
 
 import pytest
 import os
@@ -23,13 +23,19 @@ from pygw.store.rocksdb import RocksDBOptions
 from pygw.index import SpatialIndexBuilder
 from pygw.query import VectorQueryBuilder
 
-from .conftest import TEST_DIR
+from .conftest import TEST_DIR, POINT_NUMBER_FIELD, POINT_TYPE_NAME
 from .conftest import POINT_TYPE_ADAPTER
 from .conftest import TEST_DATA
 from .conftest import write_test_data
 from .conftest import results_as_list
 
+
 # Test Additions #
+from ..statistics.data_type import CountStatistic
+from ..statistics.field import NumericRangeStatistic
+from ..statistics.index import DuplicateEntryCountStatistic
+
+
 def test_add_type(test_ds):
     # given
     index = SpatialIndexBuilder().create_index()
@@ -158,6 +164,7 @@ def test_delete(test_ds):
     assert len(test_ds.get_types()) == 1
     assert len(res) == (len(TEST_DATA) - 10)
 
+
 # Test Delete All #
 def test_delete_all(test_ds):
     # given
@@ -214,6 +221,7 @@ def test_copy(test_ds):
 
     ds2.delete_all()
 
+
 def test_copy_by_query(test_ds):
     # given
     options = RocksDBOptions()
@@ -252,6 +260,7 @@ def test_copy_by_query(test_ds):
 
     ds2.delete_all()
 
+
 # Test Writer #
 def test_create_writer(test_ds):
     # given
@@ -304,6 +313,120 @@ def test_write(test_ds):
     # then
     assert len(res) == len(TEST_DATA)
 
+
+def test_add_get_statistics(test_ds):
+    # given
+    adapter = POINT_TYPE_ADAPTER
+    index = SpatialIndexBuilder().set_name('idx').create_index()
+    test_ds.add_type(adapter, index)
+    write_test_data(test_ds, index)
+
+    duplicate_entry_count_stat = DuplicateEntryCountStatistic('idx')
+    duplicate_entry_count_stat.set_tag('test')
+    count_stat = CountStatistic(POINT_TYPE_NAME)
+    count_stat.set_tag('test')
+    numeric_range_statistic = NumericRangeStatistic(POINT_TYPE_NAME, POINT_NUMBER_FIELD)
+    numeric_range_statistic.set_tag('test')
+
+    # when
+    test_ds.add_statistic(duplicate_entry_count_stat, count_stat, numeric_range_statistic)
+
+    # then
+    duplicate_entry_count_stat = test_ds.get_index_statistic(DuplicateEntryCountStatistic.STATS_TYPE, 'idx', 'test')
+    assert isinstance(duplicate_entry_count_stat, DuplicateEntryCountStatistic)
+    assert duplicate_entry_count_stat.get_tag() == 'test'
+    assert duplicate_entry_count_stat.get_index_name() == 'idx'
+    count_stat = test_ds.get_data_type_statistic(CountStatistic.STATS_TYPE, POINT_TYPE_NAME, 'test')
+    assert isinstance(count_stat, CountStatistic)
+    assert count_stat.get_tag() == 'test'
+    assert count_stat.get_type_name() == POINT_TYPE_NAME
+    numeric_range_statistic = test_ds.get_field_statistic(
+        NumericRangeStatistic.STATS_TYPE, POINT_TYPE_NAME, POINT_NUMBER_FIELD, 'test')
+    assert isinstance(numeric_range_statistic, NumericRangeStatistic)
+    assert numeric_range_statistic.get_tag() == 'test'
+    assert numeric_range_statistic.get_type_name() == POINT_TYPE_NAME
+    assert numeric_range_statistic.get_field_name() == POINT_NUMBER_FIELD
+
+    index_stats = test_ds.get_index_statistics('idx')
+    assert any(stat.get_tag() == 'test' and isinstance(stat, DuplicateEntryCountStatistic) for stat in index_stats)
+    data_type_stats = test_ds.get_data_type_statistics(POINT_TYPE_NAME)
+    assert any(stat.get_tag() == 'test' and isinstance(stat, CountStatistic) for stat in data_type_stats)
+    field_stats = test_ds.get_field_statistics(POINT_TYPE_NAME, POINT_NUMBER_FIELD)
+    assert any(stat.get_tag() == 'test' and isinstance(stat, NumericRangeStatistic) for stat in field_stats)
+
+
+def test_stat_recalc_statistics(test_ds):
+    # given
+    adapter = POINT_TYPE_ADAPTER
+    index = SpatialIndexBuilder().set_name('idx').create_index()
+    test_ds.add_type(adapter, index)
+    write_test_data(test_ds, index)
+
+    duplicate_entry_count_stat = DuplicateEntryCountStatistic('idx')
+    duplicate_entry_count_stat.set_tag('test')
+    count_stat = CountStatistic(POINT_TYPE_NAME)
+    count_stat.set_tag('test')
+    numeric_range_statistic = NumericRangeStatistic(POINT_TYPE_NAME, POINT_NUMBER_FIELD)
+    numeric_range_statistic.set_tag('test')
+    test_ds.add_empty_statistic(duplicate_entry_count_stat, count_stat, numeric_range_statistic)
+    assert test_ds.get_statistic_value(duplicate_entry_count_stat) == 0
+    assert test_ds.get_statistic_value(count_stat) == 0
+    numeric_range = test_ds.get_statistic_value(numeric_range_statistic)
+    assert numeric_range.get_minimum() == 0
+    assert numeric_range.get_maximum() == 0
+
+    # when
+    test_ds.recalc_statistic(duplicate_entry_count_stat, count_stat, numeric_range_statistic)
+
+    # then
+    assert test_ds.get_statistic_value(duplicate_entry_count_stat) == 0
+    assert test_ds.get_statistic_value(count_stat) == 360
+    numeric_range = test_ds.get_statistic_value(numeric_range_statistic)
+    assert numeric_range.get_minimum() == -180
+    assert numeric_range.get_maximum() == 179
+
+def test_remove_statistics(test_ds):
+    # given
+    adapter = POINT_TYPE_ADAPTER
+    index = SpatialIndexBuilder().set_name('idx').create_index()
+    test_ds.add_type(adapter, index)
+    write_test_data(test_ds, index)
+
+    duplicate_entry_count_stat = DuplicateEntryCountStatistic('idx')
+    duplicate_entry_count_stat.set_tag('test')
+    count_stat = CountStatistic(POINT_TYPE_NAME)
+    count_stat.set_tag('test')
+    numeric_range_statistic = NumericRangeStatistic(POINT_TYPE_NAME, POINT_NUMBER_FIELD)
+    numeric_range_statistic.set_tag('test')
+
+    test_ds.add_statistic(duplicate_entry_count_stat, count_stat, numeric_range_statistic)
+
+    # and
+    duplicate_entry_count_stat = test_ds.get_index_statistic(DuplicateEntryCountStatistic.STATS_TYPE, 'idx', 'test')
+    assert isinstance(duplicate_entry_count_stat, DuplicateEntryCountStatistic)
+    assert duplicate_entry_count_stat.get_tag() == 'test'
+    assert duplicate_entry_count_stat.get_index_name() == 'idx'
+    count_stat = test_ds.get_data_type_statistic(CountStatistic.STATS_TYPE, POINT_TYPE_NAME, 'test')
+    assert isinstance(count_stat, CountStatistic)
+    assert count_stat.get_tag() == 'test'
+    assert count_stat.get_type_name() == POINT_TYPE_NAME
+    numeric_range_statistic = test_ds.get_field_statistic(
+        NumericRangeStatistic.STATS_TYPE, POINT_TYPE_NAME, POINT_NUMBER_FIELD, 'test')
+    assert isinstance(numeric_range_statistic, NumericRangeStatistic)
+    assert numeric_range_statistic.get_tag() == 'test'
+    assert numeric_range_statistic.get_type_name() == POINT_TYPE_NAME
+    assert numeric_range_statistic.get_field_name() == POINT_NUMBER_FIELD
+
+    # when
+    test_ds.remove_statistic(duplicate_entry_count_stat, count_stat, numeric_range_statistic)
+
+    # then
+    assert test_ds.get_index_statistic(DuplicateEntryCountStatistic.STATS_TYPE, 'idx', 'test') is None
+    assert test_ds.get_data_type_statistic(CountStatistic.STATS_TYPE, POINT_TYPE_NAME, 'test') is None
+    assert test_ds.get_field_statistic(
+        NumericRangeStatistic.STATS_TYPE, POINT_TYPE_NAME, POINT_NUMBER_FIELD, 'test') is None
+
+
 def _test_base_options(options, server_side_possible=True):
     options.set_geowave_namespace("test_namespace")
     assert options.get_geowave_namespace() == "test_namespace"
@@ -326,7 +449,7 @@ def _test_base_options(options, server_side_possible=True):
     if server_side_possible:
         assert options.is_server_side_library_enabled() == server_side_library
     else:
-        assert options.is_server_side_library_enabled() == False
+        assert options.is_server_side_library_enabled() is False
 
     options.set_max_range_decomposition(42)
     assert options.get_max_range_decomposition() == 42
@@ -354,6 +477,7 @@ def test_accumulo_options():
     assert options.is_use_locality_groups() == locality_groups
     _test_base_options(options)
 
+
 def test_bigtable_options():
     options = BigTableOptions()
     options.set_scan_cache_size(42)
@@ -364,19 +488,36 @@ def test_bigtable_options():
     assert options.get_instance_id() == "test_instance_id"
     _test_base_options(options)
 
+
 def test_cassandra_options():
     options = CassandraOptions()
-    options.set_contact_point("test_contact_point")
-    assert options.get_contact_point() == "test_contact_point"
+    options.set_contact_points("test_contact_point")
+    assert options.get_contact_points() == "test_contact_point"
+    options.set_datacenter("test_datacenter")
+    assert options.get_datacenter() == "test_datacenter"
     options.set_batch_write_size(42)
     assert options.get_batch_write_size() == 42
     durable_writes = not options.is_durable_writes()
     options.set_durable_writes(durable_writes)
     assert options.is_durable_writes() == durable_writes
     options.set_replication_factor(43)
-    assert options.get_replication_factor() == 43
+    assert options.get_replication_factor() == 43    
+    options.set_gc_grace_seconds(44)
+    assert options.get_gc_grace_seconds() == 44
+    table_options = {
+        "test_key_1": "test_value_1",
+        "test_key_2": "test_value_2"
+    }
+    options.set_table_options(table_options)
+    returned_table_options = options.get_table_options()
+    assert len(returned_table_options) == len(table_options)
+    for key in returned_table_options:
+        assert (key in table_options and returned_table_options[key] == table_options[key])
+    options.set_compaction_strategy("TimeWindowCompactionStrategy")
+    assert options.get_compaction_strategy() == "TimeWindowCompactionStrategy"
     _test_base_options(options, False)
 
+
 def test_dynamodb_options():
     options = DynamoDBOptions()
     options.set_region("us-east-1")
@@ -400,6 +541,7 @@ def test_dynamodb_options():
     assert options.get_max_connections() == 44
     _test_base_options(options, False)
 
+
 def test_hbase_options():
     options = HBaseOptions()
     options.set_zookeeper("test_zookeeper")
@@ -414,20 +556,27 @@ def test_hbase_options():
     assert options.get_coprocessor_jar() == "test_jar"
     _test_base_options(options)
 
+
 def test_kudu_options():
     options = KuduOptions()
     options.set_kudu_master("test_master")
     assert options.get_kudu_master() == "test_master"
     _test_base_options(options, False)
 
+
 def test_redis_options():
     options = RedisOptions()
     options.set_address("test_address")
     assert options.get_address() == "test_address"
     options.set_compression("L4Z")
     assert options.get_compression() == "L4Z"
+    options.set_username("test_username")
+    assert options.get_username() == "test_username"
+    options.set_password("test_password")
+    assert options.get_password() == "test_password"
     _test_base_options(options, False)
 
+
 def test_rocksdb_options():
     options = RocksDBOptions()
     options.set_directory("test_directory")
